#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *Scrollbar.width 10
	}
    }
    
}
#############################################################################
# Visual Tcl v1.51 Project
#

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
proc Window {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
}

if {![info exists vTcl(sourcing)]} {
proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget

    set widget($alias) $target
    set widget(rev,$target) $alias

    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }

    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target

        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}

proc {vTcl:DoCmdOption} {target cmd} {
    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}

proc {vTcl:FireEvent} {target event} {
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                regsub -all %W $bind_code $target bind_code
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    # break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    switch -- $command {
        "hide" -
        "Hide" {
            Window hide $w
        }

        "show" -
        "Show" {
            Window show $w
        }

        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }

        default {
            eval $w $command $args
        }
    }
}

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    eval $w $command $args
}

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}

if {[info exists vTcl(sourcing)]} {
proc vTcl:project:info {} {
    namespace eval ::widgets::.top37 {
        array set save {}
    }
    namespace eval ::widgets::.top37.but38 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top37.mes37 {
        array set save {-justify 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top37.but75 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top37.but76 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top38 {
        array set save {}
    }
    namespace eval ::widgets::.top38.but39 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top38.lab40 {
        array set save {-anchor 1 -height 1 -justify 1 -padx 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top39 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top39.m40 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top39.lab41 {
        array set save {-height 1 -text 1}
    }
    namespace eval ::widgets::.top39.ent42 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top39.but43 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top39.but44 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top39.but47 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top39.but48 {
        array set save {-command 1 -height 1 -state 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top40 {
        array set save {}
    }
    namespace eval ::widgets::.top40.but41 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top40.lab42 {
        array set save {-anchor 1 -height 1 -justify 1 -padx 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top41 {
        array set save {}
    }
    namespace eval ::widgets::.top41.lab42 {
        array set save {-font 1 -height 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top41.but43 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top41.but44 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top42 {
        array set save {}
    }
    namespace eval ::widgets::.top42.but44 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top42.cpd37 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top42.cpd37.01 {
        array set save {-command 1 -orient 1}
    }
    namespace eval ::widgets::.top42.cpd37.02 {
        array set save {-command 1}
    }
    namespace eval ::widgets::.top42.cpd37.03 {
        array set save {-font 1 -height 1 -state 1 -width 1 -wrap 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top43 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top43.m44 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top43.but48 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top43.lab37 {
        array set save {-height 1 -text 1}
    }
    namespace eval ::widgets::.top43.but38 {
        array set save {-command 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top43.ent39 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top43.but37 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top43.but39 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top44 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top44.m45 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top44.but46 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top44.but47 {
        array set save {-command 1 -height 1 -state 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top44.but48 {
        array set save {-command 1 -height 1 -state 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top45 {
        array set save {}
    }
    namespace eval ::widgets::.top45.but46 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top45.lab47 {
        array set save {-anchor 1 -height 1 -justify 1 -padx 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top46 {
        array set save {}
    }
    namespace eval ::widgets::.top46.lab47 {
        array set save {-font 1 -height 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top46.but48 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top46.but49 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top49.m50 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top49.but38 {
        array set save {-command 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top49.ent39 {
        array set save {-background 1 -invalidcommand 1 -textvariable 1 -validate 1 -validatecommand 1}
    }
    namespace eval ::widgets::.top49.mes40 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but41 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes37 {
        array set save {-text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes38 {
        array set save {-text 1 -width 1}
    }
    namespace eval ::widgets::.top49.lab44 {
        array set save {-anchor 1 -font 1 -height 1 -justify 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes39 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but40 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.ent41 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but42 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.mes43 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but44 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.ent45 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but46 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but47 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes48 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.ent49 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but50 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but51 {
        array set save {-command 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top49.mes54 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.ent55 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but56 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but57 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but58 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.mes59 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but60 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.lab66 {
        array set save {-height 1 -relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top49.che40 {
        array set save {-command 1 -height 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top49.che42 {
        array set save {-command 1 -height 1 -onvalue 1 -text 1 -variable 1 -width 1}
    }
    namespace eval ::widgets::.top49.che43 {
        array set save {-command 1 -height 1 -onvalue 1 -text 1 -variable 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes41 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.ent42 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but43 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but45 {
        array set save {-command 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but48 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.che49 {
        array set save {-anchor 1 -height 1 -text 1 -variable 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes50 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes51 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but52 {
        array set save {-command 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.spi53 {
        array set save {-from 1 -justify 1 -textvariable 1 -to 1 -width 1}
    }
    namespace eval ::widgets::.top49.but55 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but59 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.but61 {
        array set save {-command 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top49.but64 {
        array set save {-command 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.spi66 {
        array set save {-from 1 -increment 1 -justify 1 -textvariable 1 -to 1 -width 1}
    }
    namespace eval ::widgets::.top49.mes67 {
        array set save {-anchor 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top49.ent68 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.ent69 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.but70 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but71 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but73 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top49.but74 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::.top77 {
        array set save {}
    }
    namespace eval ::widgets::.top77.lab78 {
        array set save {-height 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top77.but79 {
        array set save {-command 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top80 {
        array set save {}
    }
    namespace eval ::widgets::.top80.but81 {
        array set save {-command 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top80.lab82 {
        array set save {-anchor 1 -height 1 -justify 1 -padx 1 -relief 1 -text 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {}
    }
}
}
#################################
# USER DEFINED PROCEDURES
#
###########################################################
## Procedure:  init
###########################################################
## Procedure:  main

proc {main} {argc argv} {
wm protocol .top44 WM_DELETE_WINDOW {exit}
}

proc init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base {container 0}} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    wm focusmodel $base passive
    wm geometry $base 1x1+0+0; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vtcl.tcl"
    bindtags $base "$base Vtcl.tcl all"
    vTcl:FireEvent $base <<Create>>
    }
    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top37 {base {container 0}} {
    if {$base == ""} {
        set base .top37
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "About" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but38" "Button4" vTcl:WidgetProc "About" 1
    vTcl:DefineAlias "$base.but75" "Button36" vTcl:WidgetProc "About" 1
    vTcl:DefineAlias "$base.but76" "Button37" vTcl:WidgetProc "About" 1
    vTcl:DefineAlias "$base.mes37" "Message1" vTcl:WidgetProc "About" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 344x212+98+107; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "About"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but38 \
        -command {Window hide $widget(About)} -height 26 -text Dismiss \
        -width 82 
    message $base.mes37 \
        -justify center -relief groove \
        -text {CUPS-PDF Setup Tool

v0.2 ALPHA
(for testing only)


by Volker C. Behr

vrbehr@cip.physik.uni-wuerzburg.de
http://cip.physik.uni-wuerzburg.de/~vrbehr/cups-pdf} \
        -textvariable {} -width 327 
    button $base.but75 \
        -command {Window show $widget(License)} -height 0 -text License \
        -width 0 
    button $base.but76 \
        -command {Window show $widget(History)} -text History 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but38 \
        -in $base -x 10 -y 180 -width 90 -height 26 -anchor nw \
        -bordermode ignore 
    place $base.mes37 \
        -in $base -x 10 -y 10 -width 327 -height 162 -anchor nw \
        -bordermode ignore 
    place $base.but75 \
        -in $base -x 265 -y 180 -width 70 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but76 \
        -in $base -x 190 -y 180 -width 70 -height 25 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top38 {base {container 0}} {
    if {$base == ""} {
        set base .top38
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Confhelp" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but39" "Button7" vTcl:WidgetProc "Confhelp" 1
    vTcl:DefineAlias "$base.lab40" "Label4" vTcl:WidgetProc "Confhelp" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 498x171+348+12; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Help on Configuration"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but39 \
        -command {Window hide $widget(Confhelp)} -height 26 -text Dismiss \
        -width 177 
    label $base.lab40 \
        -anchor w -height 0 -justify left -padx 5 -relief groove \
        -text {location of GhostScript binary (gs)} -textvariable chelptext \
        -width 468 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but39 \
        -in $base -x 160 -y 140 -width 175 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.lab40 \
        -in $base -x 15 -y 10 -width 470 -height 125 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top39 {base {container 0}} {
    if {$base == ""} {
        set base .top39
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Build" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but43" "Button40" vTcl:WidgetProc "Build" 1
    vTcl:DefineAlias "$base.but44" "Button41" vTcl:WidgetProc "Build" 1
    vTcl:DefineAlias "$base.but47" "Button42" vTcl:WidgetProc "Build" 1
    vTcl:DefineAlias "$base.but48" "Button43" vTcl:WidgetProc "Build" 1
    vTcl:DefineAlias "$base.ent42" "Entry9" vTcl:WidgetProc "Build" 1
    vTcl:DefineAlias "$base.lab41" "Label9" vTcl:WidgetProc "Build" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m40" 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 608x136+302+268; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "CUPS-PDF Build"
    vTcl:FireEvent $base <<Create>>
    }
    menu $base.m40 \
        -tearoff 1 
    $base.m40 add command \
        -accelerator {} -command {Window hide $widget(Build)} -image {} \
        -label Return 
    label $base.lab41 \
        -height 0 -text {Backend Directory} 
    entry $base.ent42 \
        -background white -textvariable backenddir -width 268 
    button $base.but43 \
        -command {set backenddir $backenddir_d} -text Default 
    button $base.but44 \
        -command {set bhelptext $backend_h; Window show $widget(Buildhelp)} \
        -text Help 
    button $base.but47 \
        \
        -command {if { [catch {exec ./configure --with-backenddir=$backenddir} buildlog] } then {set bstatus "Configure: ERROR"} else {set bstatus "Configure: Success"; $widget(Button43) configure -state normal}; $widget(CLogWindow) configure -state normal; $widget(CLogWindow) delete 0.0 end; $widget(CLogWindow) insert end $buildlog; $widget(CLogWindow) configure -state disabled; set buildlog ""; Window show $widget(Buildinfo)} \
        -height 26 -text {Prepare: Run "./configure"} -width 237 
    button $base.but48 \
        \
        -command {if { [catch {exec make} buildlog] } then {set bstatus "Make: ERROR"} else {set bstatus "Make: Success"; $widget(Installbutton) configure -state normal}; $widget(CLogWindow) configure -state normal; $widget(CLogWindow) delete 0.0 end; $widget(CLogWindow) insert end $buildlog; $widget(CLogWindow) configure -state disabled; set buildlog ""; Window show $widget(Buildinfo)} \
        -height 26 -state disabled -text {Compile: Run "make"} -width 237 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.lab41 \
        -in $base -x 15 -y 25 -height 25 -anchor nw -bordermode ignore 
    place $base.ent42 \
        -in $base -x 150 -y 25 -width 268 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but43 \
        -in $base -x 435 -y 25 -height 25 -anchor nw -bordermode ignore 
    place $base.but44 \
        -in $base -x 540 -y 25 -height 25 -anchor nw -bordermode ignore 
    place $base.but47 \
        -in $base -x 15 -y 90 -width 250 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but48 \
        -in $base -x 340 -y 90 -width 250 -height 25 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top40 {base {container 0}} {
    if {$base == ""} {
        set base .top40
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Buildhelp" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but41" "Button44" vTcl:WidgetProc "Buildhelp" 1
    vTcl:DefineAlias "$base.lab42" "Label10" vTcl:WidgetProc "Buildhelp" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 497x136+331+39; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Help on Building"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but41 \
        -command {Window hide $widget(Buildhelp)} -height 101 -text Dismiss \
        -width 62 
    label $base.lab42 \
        -anchor w -height 0 -justify left -padx 5 -relief groove \
        -textvariable bhelptext -width 470 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but41 \
        -in $base -x 165 -y 105 -width 175 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.lab42 \
        -in $base -x 15 -y 10 -width 470 -height 90 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top41 {base {container 0}} {
    if {$base == ""} {
        set base .top41
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Buildinfo" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but43" "Button45" vTcl:WidgetProc "Buildinfo" 1
    vTcl:DefineAlias "$base.but44" "Button46" vTcl:WidgetProc "Buildinfo" 1
    vTcl:DefineAlias "$base.lab42" "Label11" vTcl:WidgetProc "Buildinfo" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 227x99+82+450; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Build Infobox"
    vTcl:FireEvent $base <<Create>>
    }
    label $base.lab42 \
        -font {Helvetica -14 bold} -height 0 -relief groove -text {} \
        -textvariable bstatus -width 208 
    button $base.but43 \
        -command {Window hide $widget(Buildinfo)} -height 26 -text Dismiss \
        -width 112 
    button $base.but44 \
        -command {Window show $widget(ConsoleLog)} -height 26 \
        -text {Show log} -width 69 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.lab42 \
        -in $base -x 10 -y 10 -width 208 -height 45 -anchor nw \
        -bordermode ignore 
    place $base.but43 \
        -in $base -x 10 -y 65 -width 112 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but44 \
        -in $base -x 145 -y 65 -width 70 -height 25 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top42 {base {container 0}} {
    if {$base == ""} {
        set base .top42
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "ConsoleLog" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but44" "Button47" vTcl:WidgetProc "ConsoleLog" 1
    vTcl:DefineAlias "$base.cpd37" "Frame3" vTcl:WidgetProc "ConsoleLog" 1
    vTcl:DefineAlias "$base.cpd37.01" "Scrollbar6" vTcl:WidgetProc "ConsoleLog" 1
    vTcl:DefineAlias "$base.cpd37.02" "Scrollbar7" vTcl:WidgetProc "ConsoleLog" 1
    vTcl:DefineAlias "$base.cpd37.03" "CLogWindow" vTcl:WidgetProc "ConsoleLog" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 631x657+327+38; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Console Log"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but44 \
        -command {Window hide $widget(ConsoleLog)} -height 26 -text Dismiss \
        -width 96 
    frame $base.cpd37 \
        -borderwidth 1 -relief raised -height 30 -width 30 
    scrollbar $base.cpd37.01 \
        -command "$base.cpd37.03 xview" -orient horizontal 
    scrollbar $base.cpd37.02 \
        -command "$base.cpd37.03 yview" 
    text $base.cpd37.03 \
        -font {Helvetica -12 bold} -height 10 -state disabled -width 20 \
        -wrap word -xscrollcommand "$base.cpd37.01 set" \
        -yscrollcommand "$base.cpd37.02 set" 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but44 \
        -in $base -x 270 -y 615 -width 96 -height 26 -anchor nw \
        -bordermode ignore 
    place $base.cpd37 \
        -in $base -x 10 -y 15 -width 610 -height 580 -anchor nw \
        -bordermode inside 
    grid columnconf $base.cpd37 0 -weight 1
    grid rowconf $base.cpd37 0 -weight 1
    grid $base.cpd37.01 \
        -in $base.cpd37 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky ew 
    grid $base.cpd37.02 \
        -in $base.cpd37 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky ns 
    grid $base.cpd37.03 \
        -in $base.cpd37 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top43 {base {container 0}} {
    if {$base == ""} {
        set base .top43
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Install" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but37" "Button51" vTcl:WidgetProc "Install" 1
    vTcl:DefineAlias "$base.but38" "Button50" vTcl:WidgetProc "Install" 1
    vTcl:DefineAlias "$base.but39" "Button52" vTcl:WidgetProc "Install" 1
    vTcl:DefineAlias "$base.but48" "Button49" vTcl:WidgetProc "Install" 1
    vTcl:DefineAlias "$base.ent39" "Entry10" vTcl:WidgetProc "Install" 1
    vTcl:DefineAlias "$base.lab37" "Label13" vTcl:WidgetProc "Install" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m44" 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 609x136+302+333; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "CUPS-PDF Install"
    vTcl:FireEvent $base <<Create>>
    }
    menu $base.m44 \
        -tearoff 1 
    $base.m44 add command \
        -accelerator {} -command {Window hide $widget(Install)} -image {} \
        -label Return 
    button $base.but48 \
        -command {set ihelptext $model_h; Window show $widget(Installhelp)} \
        -height 25 -text Help -width 52 
    label $base.lab37 \
        -height 0 -text {Model Directory} 
    button $base.but38 \
        -command {set modeldir $modeldir_d} -text Default -width 0 
    entry $base.ent39 \
        -background white -textvariable modeldir -width 268 
    button $base.but37 \
        \
        -command {if { [catch {exec make -- install} installlog] } then {set istatus "Make install: ERROR"} else {set istatus "Make install: Success"}; $widget(CLogWindow) configure -state normal; $widget(CLogWindow) delete 0.0 end; $widget(CLogWindow) insert end $installlog; $widget(CLogWindow) configure -state disabled; set installlog ""; Window show $widget(Installinfo)} \
        -height 0 -text {Install: Run "make install"} -width 0 
    button $base.but39 \
        \
        -command {if { [catch {exec install -b -v -D -m 644 extra/PostscriptColor.ppd.gz $modeldir/PostscriptColor.ppd.gz} installlog] } then {set istatus "Install PPD: ERROR"} else {set istatus "Install PPD: Success"}; $widget(CLogWindow) configure -state normal; $widget(CLogWindow) delete 0.0 end; $widget(CLogWindow) insert end $installlog; $widget(CLogWindow) configure -state disabled; set installlog ""; Window show $widget(Installinfo)} \
        -height 0 -text {Install PPD file} -width 0 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but48 \
        -in $base -x 540 -y 25 -width 52 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.lab37 \
        -in $base -x 20 -y 25 -height 25 -anchor nw -bordermode ignore 
    place $base.but38 \
        -in $base -x 435 -y 25 -height 25 -anchor nw -bordermode ignore 
    place $base.ent39 \
        -in $base -x 150 -y 25 -width 268 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but37 \
        -in $base -x 15 -y 90 -width 250 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but39 \
        -in $base -x 340 -y 90 -width 250 -height 25 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top44 {base {container 0}} {
    if {$base == ""} {
        set base .top44
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Main" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but46" "Button1" vTcl:WidgetProc "Main" 1
    vTcl:DefineAlias "$base.but47" "Buildbutton" vTcl:WidgetProc "Main" 1
    vTcl:DefineAlias "$base.but48" "Installbutton" vTcl:WidgetProc "Main" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m45" 
    wm focusmodel $base passive
    wm geometry $base 246x202+62+121; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "CUPS-PDF Setup Tool"
    vTcl:FireEvent $base <<Create>>
    }
    menu $base.m45 \
        -tearoff 1 
    $base.m45 add command \
        -accelerator {} -command exit -image {} -label Exit 
    $base.m45 add command \
        -accelerator {} -command {Window show $widget(About)} -image {} \
        -label About 
    button $base.but46 \
        \
        -command {if {[info exists configcalled]} then { Window show $widget(Conf) } else {set cpghostscript_h "location of GhostScript binary (gs)"; set cppdfver_h "PDF version to be created - can be \"1.4\", \"1.3\" or \"1.2\""; set cpspool_h "CUPS-PDF spool directory"; set cpout_h "CUPS-PDF output directory\nspecial qualifier: \"\$HOME\" will set output directory dynamically\n\tto the user's home directory (also true for an anonymous\n\tuser - make sure the home directory exists and is accessible!)\nin case CPOUT is an NFS export make sure it is exported without\nroot_squash!"; set cphomesub_h "CUPS-PDF subdirectory for output in a user's home directory\nonly required if CPOUT is set to \"\$HOME\"\ncan be \"\" or a single relative directory name"; set cpcut_h "removing file name extensions before appending .pdf to output\nextensions will only be removed if _both_ the following criteria are met:\n - the extension (w/o the dot) is not longer than CPOUT characters\n - the remaining filename has a minimal length of 1 character\nset CPCUT to -1 in order to disable cutting\nrecommended values:\tpure UNIX environment\t: -1\n\t\t\tmixed environments\t:  3 "; set cpuserprefix_h "some installations require a domain prefix added to the user name\n(special characters must be masked, e.g. \\\\ for a backslash)\nleave blank for no prefix"; set cpdirprefix_h "if a prefix was defined above this switch toggels whether to include\nthe prefix in the output directory's name (if not \$HOME) or not\n0: do not include, 1: include"; set cplog_h "CUPS-PDF log directory\nset to \"\" (empty string) to disable all logging"; set cplogtype_h "log-mode\n1: errors\n2: status (i.e. activity)\n4: debug - this will generate a lot of log-output!\nadd up values to combine options\nif logging is disabled these setting have no effect"; set cpanonuser_h "user for anonymous PDF creation (this might be a security issue)\nset to \"\" (empty string) to disable anonymous"; set cpanondirname_h "directoryname for anonymously created PDF files\nif anonymous access is disabled this setting has no effect"; set cpspool_d "/var/spool/cups/tmp"; set cpspool $cpspool_d; set cpout_d "/var/tmp/cups-pdf"; set cpout $cpout_d; set cphomesub_d "cups-pdf"; set cphomesub $cphomesub_d; set cplog_d "/var/log/cups"; set cplog $cplog_d; set cppdfver_d "1.4"; set cppdfver $cppdfver_d; set cpanonuser_d "nobody"; set cpanonuser $cpanonuser_d; set cpanondirname_d "ANONYMOUS"; set cpanondirname $cpanondirname_d; set cpcut "3"; set cplogtype "3"; $widget(Checkbutton4) select; $widget(Checkbutton7) select; set cpghostscript "gs"; set configcalled "1"; Window show $widget(Conf)}} \
        -height 41 -text {Step 1 - Configure} -width 212 
    button $base.but47 \
        \
        -command {if {[info exists buildcalled]} then { Window show $widget(Build) } else {set backenddir_d "/usr/lib/cups/backend"; set backenddir $backenddir_d; set backend_h "directory containing the backends of CUPS"; set buildcalled "1"; Window show $widget(Build)}} \
        -height 41 -state disabled -text {Step 2 - Build} -width 212 
    button $base.but48 \
        \
        -command {if {[info exists installcalled]} then { Window show $widget(Install) } else {set modeldir_d "/usr/share/cups/model"; set modeldir $modeldir_d; set model_h "directory containing the PPD files for CUPS\n(i.e. the description files for the printers)"; set installcalled "1"; Window show $widget(Install)}} \
        -height 41 -state disabled -text {Step 3 - Install} -width 212 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but46 \
        -in $base -x 15 -y 25 -width 212 -height 41 -anchor nw \
        -bordermode ignore 
    place $base.but47 \
        -in $base -x 15 -y 80 -width 212 -height 41 -anchor nw \
        -bordermode ignore 
    place $base.but48 \
        -in $base -x 15 -y 135 -width 212 -height 41 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top45 {base {container 0}} {
    if {$base == ""} {
        set base .top45
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Installhelp" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but46" "Button48" vTcl:WidgetProc "Installhelp" 1
    vTcl:DefineAlias "$base.lab47" "Label12" vTcl:WidgetProc "Installhelp" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 498x137+392+9; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Help on Installation"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but46 \
        -command {Window hide $widget(Installhelp)} -height 0 -text Dismiss \
        -width 0 
    label $base.lab47 \
        -anchor w -height 0 -justify left -padx 5 -relief groove \
        -textvariable ihelptext -width 469 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but46 \
        -in $base -x 170 -y 105 -width 175 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.lab47 \
        -in $base -x 15 -y 10 -width 469 -height 90 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top46 {base {container 0}} {
    if {$base == ""} {
        set base .top46
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Installinfo" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but48" "Button53" vTcl:WidgetProc "Installinfo" 1
    vTcl:DefineAlias "$base.but49" "Button54" vTcl:WidgetProc "Installinfo" 1
    vTcl:DefineAlias "$base.lab47" "Label14" vTcl:WidgetProc "Installinfo" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 289x99+7+477; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Install Infobox"
    vTcl:FireEvent $base <<Create>>
    }
    label $base.lab47 \
        -font {Helvetica -14 bold} -height 0 -relief groove \
        -textvariable istatus -width 271 
    button $base.but48 \
        -command {Window hide $widget(Installinfo)} -text Dismiss 
    button $base.but49 \
        -command {Window show $widget(ConsoleLog)} -height 25 \
        -text {Show Log} -width 75 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.lab47 \
        -in $base -x 10 -y 10 -width 271 -height 45 -anchor nw \
        -bordermode ignore 
    place $base.but48 \
        -in $base -x 10 -y 65 -width 112 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but49 \
        -in $base -x 205 -y 65 -width 75 -height 25 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top49 {base {container 0}} {
    if {$base == ""} {
        set base .top49
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Conf" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but38" "Button5" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but40" "Button8" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but41" "Button6" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but42" "Button9" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but43" "Button21" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but44" "Button10" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but45" "Button22" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but46" "Button11" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but47" "Button12" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but48" "Button23" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but50" "Button13" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but51" "Button14" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but52" "Button24" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but55" "Button26" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but56" "Button17" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but57" "Button18" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but58" "Button19" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but59" "Button27" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but60" "Button20" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but61" "Button28" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but64" "Button29" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but70" "Button30" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but71" "Button31" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but73" "Button34" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.but74" "Button35" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.che40" "Checkbutton4" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.che42" "Checkbutton6" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.che43" "Checkbutton7" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.che49" "Checkbutton8" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent39" "Entry1" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent41" "Entry2" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent42" "Entry6" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent45" "Entry3" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent49" "Entry4" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent55" "Entry5" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent68" "Entry7" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.ent69" "Entry8" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.lab44" "Label2" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.lab66" "Label6" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes37" "Message4" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes38" "Message5" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes39" "Message6" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes40" "Message3" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes41" "Message11" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes43" "Message7" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes48" "Message8" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes50" "Message12" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes51" "Message13" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes54" "Message9" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes59" "Message10" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.mes67" "Message14" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.spi53" "Spinbox1" vTcl:WidgetProc "Conf" 1
    vTcl:DefineAlias "$base.spi66" "Spinbox3" vTcl:WidgetProc "Conf" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m50" 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 462x551+254+152; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "CUPS-PDF Configuration"
    vTcl:FireEvent $base <<Create>>
    }
    menu $base.m50 \
        -tearoff 1 
    $base.m50 add command \
        -accelerator {} \
        -command {if { [catch {set id [open "./src/cups-pdf.h" w]} error] } then {set showerror $error} else {puts $id "/* cups-pdf.h -- CUPS Backend Header File (auto-generated for version 1.3.1)\n   16.05.2003, Volker C. Behr\n   Exp. Physik V, Uni Wuerzburg\n   vrbehr@cip.physik.uni-wuerzburg.de\n   http://cip.physik.uni-wuerzburg.de/~vrbehr/cups-pdf\n\n\n   This code may be freely distributed as long as this header\n   is preserved. Changes to the code should be clearly indicated.\n\n   This code is distributed under the GPL.\n   (http://www.gnu.org/copyleft/gpl.html)\n\n   For more detailed licensing information see cups-pdf.c in the\n   corresponding version number.\t\t\t\t\t*/\n\n\n/* User-customizable settings - these were generated by the\n   CUPS-PDF Setup Tool.\t\t\t\t\t\t\t*/\n\n/*\n$cpghostscript_h\n*/\n#define CPGHOSTSCRIPT \"$cpghostscript\"\n\n/*\n$cppdfver_h\n*/\n#define CPPDFVER \"$cppdfver\"\n\n/*\n$cpspool_h\n*/\n#define CPSPOOL \"$cpspool\"\n\n/*\n$cpout_h\n*/\n#define CPOUT \"$cpout\"\n\n/*\n$cphomesub_h\n*/\n#define CPHOMESUB \"$cphomesub\"\n\n/*\n$cpcut_h\n*/\n#define CPCUT $cpcut\n\n/*\n$cpuserprefix_h\n*/\n#define CPUSERPREFIX \"$cpuserprefix\"\n\n/*\n$cpdirprefix_h\n*/\n#define CPDIRPREFIX $cpdirprefix\n\n/*\n$cplog_h\n*/\n#define CPLOG \"$cplog\"\n\n/*\n$cplogtype_h\n*/\n#define CPLOGTYPE $cplogtype\n\n/*\n$cpanonuser_h\n*/\n#define CPANONUSER \"$cpanonuser\"\n\n/*\n$cpanondirname_h\n*/\n#define CPANONDIRNAME \"$cpanondirname\"\n"; close $id; set showerror "Configuration written to ./cups-pdf.h"; $widget(Buildbutton) configure -state normal}} \
        -image {} -label {Write src/cups-pdf.h} 
    $base.m50 add command \
        -accelerator {} -command {Window hide $widget(Conf)} -image {} \
        -label Return 
    button $base.but38 \
        \
        -command {if [catch {set cpghostscript [exec which -- gs]} error] then {set showerror $error}} \
        -height 0 -text AutoDetect 
    entry $base.ent39 \
        -background white -invalidcommand {} -textvariable cpghostscript \
        -validate all \
        -validatecommand {vTcl:DoCmdOption .top49.ent39 {if { [catch {exec which -- %P} error] } then {set gsversion unknown; set showerror $error; return true} else {set gsversion [exec %P --version]; set showerror ""; return true}}} 
    message $base.mes40 \
        -anchor w -text GhostScript -width 102 
    button $base.but41 \
        \
        -command {set chelptext $cpghostscript_h; Window show $widget(Confhelp)} \
        -height 0 -text Help -width 0 
    message $base.mes37 \
        -text 7.05.6 -textvariable gsversion -width 70 
    message $base.mes38 \
        -text Version: -width 70 
    label $base.lab44 \
        -anchor sw -font {Helvetica -10} -height 0 -justify left \
        -relief groove -text {} -textvariable showerror -width 451 
    message $base.mes39 \
        -anchor w -text Spool -width 102 
    button $base.but40 \
        -command {set chelptext $cpspool_h; Window show $widget(Confhelp)} \
        -text Help 
    entry $base.ent41 \
        -background white -textvariable cpspool 
    button $base.but42 \
        -command {set cpspool $cpspool_d} -text Default 
    message $base.mes43 \
        -anchor w -text Output -width 102 
    button $base.but44 \
        -command {set chelptext $cpout_h; Window show $widget(Confhelp)} \
        -text Help 
    entry $base.ent45 \
        -background white -textvariable cpout 
    button $base.but46 \
        -command {set cpout $cpout_d} -text Default 
    button $base.but47 \
        -command {set cpout "\$HOME"} -height 25 -text HOME -width 67 
    message $base.mes48 \
        -anchor w -text Subdirectory -width 102 
    entry $base.ent49 \
        -background white -textvariable cphomesub 
    button $base.but50 \
        -command {set cphomesub $cphomesub_d} -text Default 
    button $base.but51 \
        -command {set chelptext $cphomesub_h; Window show $widget(Confhelp)} \
        -height 0 -text Help 
    message $base.mes54 \
        -anchor w -text Log -width 102 
    entry $base.ent55 \
        -background white -textvariable cplog 
    button $base.but56 \
        -command {set cplog $cplog_d} -height 0 -text Default -width 0 
    button $base.but57 \
        -command {set cplog ""} -text Disable 
    button $base.but58 \
        -command {set chelptext $cplog_h; Window show $widget(Confhelp)} \
        -text Help 
    message $base.mes59 \
        -anchor w -text Loglevel -width 102 
    button $base.but60 \
        -command {set chelptext $cplogtype_h; Window show $widget(Confhelp)} \
        -text Help 
    label $base.lab66 \
        -height 0 -relief groove -text 3 -textvariable cplogtype -width 23 
    checkbutton $base.che40 \
        -command {set cplogtype [expr $cperror + $cpstatus + $cpdebug]} \
        -height 0 -text Error -variable cperror 
    checkbutton $base.che42 \
        -command {set cplogtype [expr $cperror + $cpstatus + $cpdebug]} \
        -height 0 -onvalue 4 -text Debug -variable cpdebug -width 0 
    checkbutton $base.che43 \
        -command {set cplogtype [expr $cperror + $cpstatus + $cpdebug]} \
        -height 0 -onvalue 2 -text Status -variable cpstatus -width 0 
    message $base.mes41 \
        -anchor w -text {Domain Prefix} -width 102 
    entry $base.ent42 \
        -background white -textvariable cpuserprefix 
    button $base.but43 \
        -command {set cpuserprefix ""} -text Disable 
    button $base.but45 \
        \
        -command {set chelptext $cpdirprefix_h; Window show $widget(Confhelp)} \
        -text Help -width 0 
    button $base.but48 \
        \
        -command {set chelptext $cpuserprefix_h; Window show $widget(Confhelp)} \
        -text Help 
    checkbutton $base.che49 \
        -anchor w -height 22 -text {Add to directory name} \
        -variable cpdirprefix -width 211 
    message $base.mes50 \
        -anchor w -text {Cut extensions} -width 102 
    message $base.mes51 \
        -anchor w -text {PDF Version} -width 102 
    button $base.but52 \
        -command {set chelptext $cpcut_h; Window show $widget(Confhelp)} \
        -text Help -width 0 
    spinbox $base.spi53 \
        -from -1.0 -justify right -textvariable cpcut -to 100.0 -width 34 
    button $base.but55 \
        -command {set cpcut "-1"} -height 25 -text {Disable (UNIX)} \
        -width 102 
    button $base.but59 \
        -command {set cpcut "3"} -height 25 -text {Default (Win)} -width 102 
    button $base.but61 \
        -command {set chelptext $cppdfver_h; Window show $widget(Confhelp)} \
        -height 0 -text Help 
    button $base.but64 \
        -command {set cppdfver $cppdfver_d} -text Default -width 0 
    spinbox $base.spi66 \
        -from 1.2 -increment 0.1 -justify right -textvariable cppdfver \
        -to 1.4 -width 34 
    message $base.mes67 \
        -anchor w -text Anonymous -width 102 
    entry $base.ent68 \
        -background white -textvariable cpanonuser 
    entry $base.ent69 \
        -background white -textvariable cpanondirname 
    button $base.but70 \
        \
        -command {set chelptext $cpanondirname_h; Window show $widget(Confhelp)} \
        -text Help 
    button $base.but71 \
        -command {set chelptext $cpanonuser_h; Window show $widget(Confhelp)} \
        -text Help 
    button $base.but73 \
        -command {set cpanonuser ""} -text Disable 
    button $base.but74 \
        \
        -command {set cpanonuser $cpanonuser_d; set cpanondirname $cpanondirname_d} \
        -text Default 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but38 \
        -in $base -x 280 -y 15 -height 25 -anchor nw -bordermode ignore 
    place $base.ent39 \
        -in $base -x 120 -y 15 -height 25 -anchor nw -bordermode ignore 
    place $base.mes40 \
        -in $base -x 10 -y 15 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but41 \
        -in $base -x 400 -y 15 -height 25 -anchor nw -bordermode ignore 
    place $base.mes37 \
        -in $base -x 200 -y 45 -height 25 -anchor nw -bordermode ignore 
    place $base.mes38 \
        -in $base -x 120 -y 45 -height 25 -anchor nw -bordermode ignore 
    place $base.lab44 \
        -in $base -x 5 -y 525 -width 451 -height 20 -anchor nw \
        -bordermode ignore 
    place $base.mes39 \
        -in $base -x 10 -y 80 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but40 \
        -in $base -x 400 -y 80 -height 25 -anchor nw -bordermode ignore 
    place $base.ent41 \
        -in $base -x 120 -y 80 -height 25 -anchor nw -bordermode ignore 
    place $base.but42 \
        -in $base -x 280 -y 80 -height 25 -anchor nw -bordermode ignore 
    place $base.mes43 \
        -in $base -x 10 -y 115 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but44 \
        -in $base -x 400 -y 115 -height 25 -anchor nw -bordermode ignore 
    place $base.ent45 \
        -in $base -x 120 -y 115 -height 25 -anchor nw -bordermode ignore 
    place $base.but46 \
        -in $base -x 280 -y 115 -height 25 -anchor nw -bordermode ignore 
    place $base.but47 \
        -in $base -x 280 -y 140 -width 67 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.mes48 \
        -in $base -x 10 -y 175 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.ent49 \
        -in $base -x 120 -y 175 -height 25 -anchor nw -bordermode ignore 
    place $base.but50 \
        -in $base -x 280 -y 175 -height 25 -anchor nw -bordermode ignore 
    place $base.but51 \
        -in $base -x 400 -y 175 -height 25 -anchor nw -bordermode ignore 
    place $base.mes54 \
        -in $base -x 10 -y 210 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.ent55 \
        -in $base -x 120 -y 210 -height 25 -anchor nw -bordermode ignore 
    place $base.but56 \
        -in $base -x 280 -y 210 -height 25 -anchor nw -bordermode ignore 
    place $base.but57 \
        -in $base -x 280 -y 235 -height 25 -anchor nw -bordermode ignore 
    place $base.but58 \
        -in $base -x 400 -y 210 -height 25 -anchor nw -bordermode ignore 
    place $base.mes59 \
        -in $base -x 10 -y 270 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but60 \
        -in $base -x 400 -y 270 -height 25 -anchor nw -bordermode ignore 
    place $base.lab66 \
        -in $base -x 120 -y 270 -width 23 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.che40 \
        -in $base -x 160 -y 270 -width 72 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.che42 \
        -in $base -x 320 -y 270 -width 72 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.che43 \
        -in $base -x 240 -y 270 -width 72 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.mes41 \
        -in $base -x 10 -y 305 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.ent42 \
        -in $base -x 120 -y 305 -height 25 -anchor nw -bordermode ignore 
    place $base.but43 \
        -in $base -x 280 -y 305 -height 25 -anchor nw -bordermode ignore 
    place $base.but45 \
        -in $base -x 400 -y 330 -height 25 -anchor nw -bordermode ignore 
    place $base.but48 \
        -in $base -x 400 -y 305 -height 25 -anchor nw -bordermode ignore 
    place $base.che49 \
        -in $base -x 125 -y 330 -width 211 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.mes50 \
        -in $base -x 10 -y 365 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.mes51 \
        -in $base -x 10 -y 425 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but52 \
        -in $base -x 400 -y 365 -height 25 -anchor nw -bordermode ignore 
    place $base.spi53 \
        -in $base -x 120 -y 365 -width 50 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but55 \
        -in $base -x 280 -y 390 -width 102 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but59 \
        -in $base -x 280 -y 365 -width 102 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.but61 \
        -in $base -x 400 -y 425 -height 25 -anchor nw -bordermode ignore 
    place $base.but64 \
        -in $base -x 280 -y 425 -height 25 -anchor nw -bordermode ignore 
    place $base.spi66 \
        -in $base -x 120 -y 425 -width 50 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.mes67 \
        -in $base -x 10 -y 460 -width 100 -height 25 -anchor nw \
        -bordermode ignore 
    place $base.ent68 \
        -in $base -x 120 -y 460 -height 25 -anchor nw -bordermode ignore 
    place $base.ent69 \
        -in $base -x 120 -y 485 -height 25 -anchor nw -bordermode ignore 
    place $base.but70 \
        -in $base -x 400 -y 485 -height 25 -anchor nw -bordermode ignore 
    place $base.but71 \
        -in $base -x 400 -y 460 -height 25 -anchor nw -bordermode ignore 
    place $base.but73 \
        -in $base -x 280 -y 485 -height 25 -anchor nw -bordermode ignore 
    place $base.but74 \
        -in $base -x 280 -y 460 -height 25 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top77 {base {container 0}} {
    if {$base == ""} {
        set base .top77
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "License" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but79" "Button38" vTcl:WidgetProc "License" 1
    vTcl:DefineAlias "$base.lab78" "Label7" vTcl:WidgetProc "License" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 552x550+446+13; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "License"
    vTcl:FireEvent $base <<Create>>
    }
    label $base.lab78 \
        -height 0 -relief groove \
        -text {This code may be freely distributed as long as this header 
   is preserved. 

   This code is distributed under the GPL.
   (http://www.gnu.org/copyleft/gpl.html)

   ---------------------------------------------------------------------------

   Copyright (C) 2003  Volker C. Behr

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

   ---------------------------------------------------------------------------
  
   If you want to redistribute modified sources/binaries this header
   has to be preserved and all modifications should be clearly 
   indicated.
   In case you want to include this code into your own programs 
   I would appreaciated some feedback via email.} \
        -width 523 
    button $base.but79 \
        -command {Window hide $widget(License)} -height 0 -text Dismiss 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.lab78 \
        -in $base -x 15 -y 15 -width 523 -height 480 -anchor nw \
        -bordermode ignore 
    place $base.but79 \
        -in $base -x 240 -y 510 -height 25 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top80 {base {container 0}} {
    if {$base == ""} {
        set base .top80
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "History" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but81" "Button39" vTcl:WidgetProc "History" 1
    vTcl:DefineAlias "$base.lab82" "Label8" vTcl:WidgetProc "History" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 638x129+74+361; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "History"
    vTcl:FireEvent $base <<Create>>
    }
    button $base.but81 \
        -command {Window hide $widget(History)} -height 0 -text Dismiss 
    label $base.lab82 \
        -anchor w -height 0 -justify left -padx 5 -relief groove \
        -text {01/02/2004 : 0.3 BETA	- fully operational beta release with limited error handling
12/25/2003 : 0.2 ALPHA	- improved alpha version for testing purposes
12/24/2003 : 0.1 ALPHA	- first pre-alpha version for testing purposes only} \
        -width 618 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.but81 \
        -in $base -x 275 -y 95 -width 90 -anchor nw -bordermode ignore 
    place $base.lab82 \
        -in $base -x 10 -y 10 -width 618 -height 75 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

Window show .
Window show .top37
Window show .top38
Window show .top39
Window show .top40
Window show .top41
Window show .top42
Window show .top43
Window show .top44
Window show .top45
Window show .top46
Window show .top49
Window show .top77
Window show .top80

main $argc $argv
